summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/chatwindow/kopetechatwindowstylemanager.h')
-rw-r--r--kopete/kopete/chatwindow/kopetechatwindowstylemanager.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h b/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h
index fef09b09..74f145ca 100644
--- a/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h
+++ b/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h
@@ -54,14 +54,14 @@ public:
typedef TQMap<TQString, TQString> StyleList;
/**
* The StyleInstalltqStatus enum. It gives better return value for installStyle().
* - StyleInstallOk : The install went fine.
* - StyleNotValid : The archive didn't contain a valid Chat Window style.
* - StyleNoDirectoryValid : It didn't find a suitable directory to install the theme.
* - StyleCannotOpen : The archive couldn't be openned.
* - StyleUnknow : Unknow error.
*/
- enum StyleInstalltqStatus { StyleInstallOk = 0, StyleNotValid, StyleNoDirectoryValid, StyleCannotOpen, StyleUnknow };
+ enum StyleInstallStatus { StyleInstallOk = 0, StyleNotValid, StyleNoDirectoryValid, StyleCannotOpen, StyleUnknow };
/**
* Destructor.
@@ -91,7 +91,7 @@ public slots:
* Note that you must pass a path to a archive.
*
* @param styleBundlePath Path to the container file to install.
* @return A status code from StyleInstalltqStatus enum.
*/
int installStyle(const TQString &styleBundlePath);
@@ -54,14 +54,14 @@ public:
typedef TQMap<TQString, TQString> StyleList;
/**
- * The StyleInstalltqStatus enum. It gives better return value for installStyle().
+ * The StyleInstallStatus enum. It gives better return value for installStyle().
* - StyleInstallOk : The install went fine.
* - StyleNotValid : The archive didn't contain a valid Chat Window style.
@@ -91,7 +91,7 @@ public slots:
*
* @param styleBundlePath Path to the container file to install.
- * @return A status code from StyleInstalltqStatus enum.
+ * @return A status code from StyleInstallStatus enum.
*/
int installStyle(const TQString &styleBundlePath);